@@ -86,7 +86,7 @@ class MetadataManager:
         self.lineNumbers = False
         self.linkDefaults = defaultdict(list)
         self.localBoilerplate = config.BoolSet(default=False)
-        self.logo = ""
+        self.logo = None
         self.mailingList = None
         self.mailingListArchives = None
         self.markupShorthands = config.BoolSet(["css", "dfn", "biblio", "markup", "idl", "algorithm"])
@@ -271,8 +271,10 @@ class MetadataManager:
             macros["longstatus"] = config.shortToLongStatus[self.status]
         else:
             macros["longstatus"] = ""
-        if self.status in ("w3c/LCWD", "w3c/FPWD", "w3c/NOTE-FPWD", "w3c/NOTE-WD"):
+        if self.status in ("w3c/LCWD", "w3c/FPWD"):
             macros["status"] = "WD"
+        elif self.status in ("w3c/NOTE-FPWD", "w3c/NOTE-WD"):
+            macros["status"] = "DNOTE"
         elif self.status in ("w3c/WG-NOTE", "w3c/IG-NOTE"):
             macros["status"] = "NOTE"
         elif self.status == "w3c/NOTE-ED":
@@ -321,7 +323,8 @@ class MetadataManager:
             macros["snapshotid"] = self.warning[2]
         if self.warning and len(self.warning) >= 4:
             macros["snapshoturl"] = self.warning[3]
-        macros["logo"] = self.logo
+        if self.logo:
+            macros["logo"] = self.logo
         if self.repository:
             macros["repository"] = self.repository.name
             macros["repositoryurl"] = self.repository.url
