@@ -72,15 +72,15 @@ def fixupDataFiles():
     using the legacy files with the new code is quite bad!
     """
     try:
-        with open(localPath("version.txt")) as fh:
+        with open(localPath("version.txt"), encoding="utf-8") as fh:
             localVersion = int(fh.read())
     except OSError:
         localVersion = None
     try:
-        with open(remotePath("version.txt")) as fh:
+        with open(remotePath("version.txt"), encoding="utf-8") as fh:
             remoteVersion = int(fh.read())
     except OSError as err:
-        warn("Couldn't check the datafile version. Bikeshed may be unstable.\n{0}", err)
+        warn(f"Couldn't check the datafile version. Bikeshed may be unstable.\n{err}")
         return
 
     if localVersion == remoteVersion:
@@ -94,7 +94,7 @@ def fixupDataFiles():
         for filename in os.listdir(remotePath()):
             copyanything(remotePath(filename), localPath(filename))
     except Exception as err:
-        warn("Couldn't update datafiles from cache. Bikeshed may be unstable.\n{0}", err)
+        warn(f"Couldn't update datafiles from cache. Bikeshed may be unstable.\n{err}")
         return
 
 
@@ -111,7 +111,7 @@ def updateReadonlyDataFiles():
                 continue
             copyanything(localPath(filename), remotePath(filename))
     except Exception as err:
-        warn("Error copying over the datafiles:\n{0}", err)
+        warn(f"Error copying over the datafiles:\n{err}")
         return
 
 
@@ -148,7 +148,7 @@ def cleanupFiles(root, touchedPaths, dryRun=False):
             os.remove(absPath)
             oldPaths.append(relPath)
     if oldPaths:
-        say("Success! Deleted {} old files.".format(len(oldPaths)))
+        say(f"Success! Deleted {len(oldPaths)} old files.")
     else:
         say("Success! Nothing to delete.")
 
