@@ -12,16 +12,13 @@ def update(path, dryRun=False):
     try:
         response = requests.get("https://raw.githubusercontent.com/Fyrd/caniuse/master/fulldata-json/data-2.0.json")
     except Exception as e:
-        die("Couldn't download the Can I Use data.\n{0}", e)
+        die(f"Couldn't download the Can I Use data.\n{e}")
         return
 
     try:
         data = response.json(encoding="utf-8", object_pairs_hook=OrderedDict)
     except Exception as e:
-        die(
-            "The Can I Use data wasn't valid JSON for some reason. Try downloading again?\n{0}",
-            e,
-        )
+        die(f"The Can I Use data wasn't valid JSON for some reason. Try downloading again?\n{e}")
         return
 
     basicData = {"agents": [], "features": {}, "updated": data["updated"]}
@@ -45,11 +42,7 @@ def update(path, dryRun=False):
         elif "u" in s:
             return "u"
         else:
-            die(
-                "Unknown CanIUse Status '{0}' for {1}/{2}/{3}. Please report this as a Bikeshed issue.",
-                s,
-                *rest,
-            )
+            die(f"Unknown CanIUse Status '{s}' for {'/'.join(rest)}. Please report this as a Bikeshed issue.")
             return None
 
     def simplifyVersion(v):
@@ -104,7 +97,7 @@ def update(path, dryRun=False):
                 with open(p, "w", encoding="utf-8") as fh:
                     fh.write(json.dumps(feature, indent=1, ensure_ascii=False, sort_keys=True))
         except Exception as e:
-            die("Couldn't save Can I Use database to disk.\n{0}", e)
+            die(f"Couldn't save Can I Use database to disk.\n{e}")
             return
     say("Success!")
     return writtenPaths
